NaMaster: Data Structures

NaMaster

- Main Page
- Data Structures
- Files

- Data Structures
- Data Structure Index
- Data Fields

Data Structures
Here are the data structures with brief descriptions:

C nmt_binning_scheme | Full-sky bandpowers
C nmt_binning_scheme_flat | Flat-sky bandpowers
C nmt_covar_workspace | Full-sky Gaussian covariance matrix
C nmt_covar_workspace_flat | Flat-sky Gaussian covariance matrix
C nmt_curvedsky_info | Curved-sky information
C nmt_field | Full-sky field
C nmt_field_flat | Flat-sky field
C nmt_flatsky_info | Flat-sky information
C nmt_k_function | Flat-sky Fourier-space function
C nmt_master_calculator |
C nmt_workspace | Full-sky mode-coupling matrix
C nmt_workspace_flat | Flat-sky mode-coupling matrix